@@ -34,6 +34,10 @@ extern int _orc_cpu_model;
 extern int _orc_cpu_stepping;
 extern const char *_orc_cpu_name;
 
+void orc_compiler_emit_invariants (OrcCompiler *compiler);
+int orc_program_has_float (OrcCompiler *compiler);
+
+char* _orc_getenv (const char *var);
 #endif
 
 ORC_END_DECLS
